@@ -84,16 +84,20 @@ class TestRun:
         if self._mem:
             return max(self._mem)
         return None
-    
+
+    @property
+    def avg_time(self) -> float:
+        return self.time / self.repeat
+
     def __str__(self) -> str:
         output = f"<TestRun '{self.name}'\n"
         output += f'    runs:         {self.repeat:,}\n'
-        output += f'    avg time: {self.time:.4}s\n'
+        output += f'    avg time: {self.avg_time:.4}s\n'
         output += f'    avg mem:    {self.memory:.4}Mib>'
         return output
     
     def __repr__(self) -> str:
-        return f'TestRun(name="{self.name}" time={self.time:.4} mem={self.memory})'
+        return f'TestRun(name="{self.name}" avg_time={self.time:.4} avg_mem={self.memory})'
 
 class history:
     '''
